@@ -3,7 +3,7 @@
 # This file is part of dj-revproxy released under the MIT license. 
 # See the NOTICE for more information.
 
-version_info = (0, 1, 1)
+version_info = (0, 2, 0)
 __version__ =  ".".join(map(str, version_info))
 
-from revproxy.proxy import RevProxy, site_proxy
+from revproxy.proxy import proxy_request, RevProxy, site_proxy
